@@ -11,8 +11,8 @@ pub struct Parts;
 pub struct Pages;
 
 #[derive(RustEmbed)]
-#[folder = "template/styles"]
-pub struct Styles;
+#[folder = "out"]
+pub struct Compiled;
 
 fn json_helper(
     h: &Helper,
